/**
 * 重置本地存储数据
 * @param {Object} data: 用户信息
 * @param {Object} callback: 回调函数
 */
function resetStorage(data, callback) {
	var user = {};
	user.nickName = data.nickName || '';
	user.baseBusinessId = data.baseBusinessId || '';
	user.logo = data.logo || '';
	user.id = data.id || '';
	user.loginNo = data.loginNo || '';
	user.shopId = data.shopId || '';
	
	plus.storage.setItem('token', data.token);
	plus.storage.setItem('user', JSON.stringify(user));
	plus.storage.setItem('shopId', data.shopId);

	callback();
}

/*
 * 插件初始化
 */
mui.init();

/*
 * 事件初始化
 */
mui.plusReady(function () {
	h('#saveButton').tap(function () {
		if(h('#loginNo').val() == '') return plus.nativeUI.toast('请输入手机号', {duration: 'long'});
		if(h('#password').val() == '') return plus.nativeUI.toast('请输入密码', {duration: 'long'});
		
		var password = h('#password').val();
		if(password.length < 6 || password.length > 30) {
			mui.toast('请输入6-30位密码');
			return false;
		}
		
		var myreg = /^(1\d{10})$/;
		var loginNo = h('#loginNo').val();
		if(!myreg.test(loginNo)) {
			mui.toast('请填写正确的手机号码');
			return false;
		}
		
		var params = {
			loginNo: h('#loginNo').val(),
			password: md5(h('#password').val()),
			source: 'app',
			deviceNo: 'xx'
		};

		mui('#saveButton').button('loading'); //切换为loading状态
		
		var url = '/register/register/token';
		jAjax(url, 'POST', true, params, function (type, data) {
			mui('#saveButton').button('reset'); //切换为reset状态(即重置为原始的button)
			
			if (!type) return plus.nativeUI.toast('网络繁忙，请稍后重试', {duration: 'long'});
			if (data.status != '200') return plus.nativeUI.toast(data.msg, {duration: 'long'});
			
			plus.nativeUI.toast('登录成功', {duration: 'long'});
			resetStorage(data.result, function() {
				plus.webview.getWebviewById(plus.webview.all()[0].id).evalJS('menu()');
				plus.webview.getWebviewById("userInfo").evalJS('resetDom()');
				mui.back();
			});
		});
	});
	
	h('#reg').tap(function () {
		mui.openWindowWithTitle({
			id: 'register',
			url: '../register/register.html',
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "注册", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		})
	});
	
	h('#forget').tap(function () {
		mui.openWindowWithTitle({
			id: 'login.html',
			url: '../forget/forget.html',
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "忘记密码", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		})
	});
});