/**
 * 初始化用户信息
 */
var BASE_IMG_PATH = API_URL_IMG + '/img';

function initData() {
	var _token = plus.storage.getItem('token');
	if (null == _token || _token == '') return;

	var url = '/business/member/detail';
	jAjax(url, 'POST', true, null, function (type, data) {
		if (!type) return plus.nativeUI.toast('网络繁忙，请稍后重试', {
			duration: 'long'
		});
		if (data.status != '200') return plus.nativeUI.toast(data.msg, {
			duration: 'long'
		});
		if (data.result == null || data.result == undefined) return plus.nativeUI.toast('网络繁忙，请稍后重试', {
			duration: 'long'
		});

		resetStorage(data.result, resetDom);
	});
}

/**
 * 重置本地存储数据
 * @param {Object} data: 用户信息
 * @param {Function} callback: 回调函数
 */
function resetStorage(data, callback) {
	var user = {};
	user.nickName = data.nickName || '';
	user.baseBusinessId = data.baseBusinessId || '';
	user.name = data.name || '';
	user.logo = data.logo || '';
	user.deviceNo = data.deviceNo || '';
	user.id = data.id || '';
	user.loginNo = data.loginNo || '';
	user.shopId = data.shopId || '';
	user.logo = data.logo || '';
	plus.storage.setItem('user', JSON.stringify(user));

	callback();
}

/**
 * 重置DOM数据及状态
 */
function resetDom() {
	var _user = plus.storage.getItem('user'),
		_token = plus.storage.getItem('token');
	if (_user == undefined || _user == '' || _user == null || _token == undefined || _token == '' || _token == null) {

		h('#editUserGroup').addClass('hide');
		h('#loginUser').removeClass('hide');
		h('.logined').addClass('hide');
	} else {
		_user = JSON.parse(_user);
		h('#nickName').html(_user.nickName);
		h('#loginNo').html(_user.loginNo);
		if (_user.logo != null && _user.logo != '') {
			h('#logo').attr('src', BASE_IMG_PATH + _user.logo);
		}

		h('#loginUser').addClass('hide');
		h('#editUserGroup').removeClass('hide');
		h('.logined').removeClass('hide');
	}
}

/*
 * 插件初始化
 */
mui.init();

/*
 * 事件初始化
 */
mui.plusReady(function () {
	// 初始化用户信息
	initData();

	// 修改用户信息事件
	h('#editUser').tap(function (e) {
		var logo = document.getElementById('logo').src;
		var nickName = document.getElementById('nickName').innerText;
		var loginNo = document.getElementById('loginNo').innerText;

		if (e.target.id === 'setting') return;
		mui.openWindowWithTitle({
			url: '../edit_user/edit_user.html',
			id: 'editUser',
			show: {
				aniShow: 'pop-in'
			},
			extras: {
				logo: logo,
				nickName: nickName,
				loginNo: loginNo
			},
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "编辑资料", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		})
	});

	// 设置事件
	h('#setting').tap(function () {
		mui.openWindowWithTitle({
			url: '../setting/setting.html',
			id: 'settingUser',
			show: {
				aniShow: 'pop-in'
			},
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "设置", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		})
	});

	// 登录事件
	h('#login').tap(function () {
		mui.openWindowWithTitle({
			url: '../../login/login.html',
			id: 'login',
			show: {
				aniShow: 'pop-in'
			},
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "登录", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		});
	});

	// 关于我们事件
	h('#about').tap(function () {
		mui.openWindowWithTitle({
			url: '../about/about.html',
			id: 'about',
			show: {
				aniShow: 'pop-in'
			},
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "关于我们", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		});
	});

	// 检查版本事件
	h('#checkVersion').tap(function () {
		plus.runtime.getProperty(plus.runtime.appid, function (inf) {
			wgtVer = inf.version;
			checkUpdate(wgtVer, true);
		});
	});

	// 显示app版本
	plus.runtime.getProperty(plus.runtime.appid, function (inf) {
		h('#version').html('v' + inf.version);
	});


	h('#extButton').tap(function () {
		mui.confirm('确认退出', '', '确认', function (e) {
			if (e.index == 0) {
				plus.storage.clear('shopInfo');
				plus.storage.clear();
				plus.webview.getWebviewById(plus.webview.all()[0].id).evalJS('menu()');
				plus.webview.getWebviewById("userInfo").reload();
			}
		})
	});

	h('#edit_pwd').tap(function () {
		mui.openWindowWithTitle({
			id: 'editPwd',
			url: '../edit_pwd/edit_pwd.html',
			waiting: {
				title: '正在加载...'
			}
		}, {
			title: { //标题配置
				text: "修改密码", //标题文字
			},
			back: { //左上角返回箭头
				image: {
					base64Data: backBase64
				}
			}
		})
	});
});